@@ -595,6 +595,8 @@ pub const CURLOPT_PROXY_CAPATH: CURLoption = CURLOPTTYPE_OBJECTPOINT + 247;
 pub const CURLOPT_PROXY_SSLCERT: CURLoption = CURLOPTTYPE_OBJECTPOINT + 254;
 pub const CURLOPT_PROXY_SSLKEY: CURLoption = CURLOPTTYPE_OBJECTPOINT + 256;
 
+pub const CURLOPT_UPLOAD_BUFFERSIZE: CURLoption = CURLOPTTYPE_LONG + 280;
+
 pub const CURLOPT_MAXAGE_CONN: CURLoption = CURLOPTTYPE_LONG + 288;
 
 pub const CURLOPT_SSLCERT_BLOB: CURLoption = CURLOPTTYPE_BLOB + 291;
@@ -1077,6 +1079,19 @@ extern "C" {
         timeout_ms: c_int,
         ret: *mut c_int,
     ) -> CURLMcode;
+
+    #[cfg(feature = "poll_7_68_0")]
+    pub fn curl_multi_poll(
+        multi_handle: *mut CURLM,
+        extra_fds: *mut curl_waitfd,
+        extra_nfds: c_uint,
+        timeout_ms: c_int,
+        ret: *mut c_int,
+    ) -> CURLMcode;
+
+    #[cfg(feature = "poll_7_68_0")]
+    pub fn curl_multi_wakeup(multi_handle: *mut CURLM) -> CURLMcode;
+
     pub fn curl_multi_perform(multi_handle: *mut CURLM, running_handles: *mut c_int) -> CURLMcode;
     pub fn curl_multi_cleanup(multi_handle: *mut CURLM) -> CURLMcode;
     pub fn curl_multi_info_read(
@@ -1111,3 +1126,8 @@ extern "C" {
 pub fn rust_crate_version() -> &'static str {
     env!("CARGO_PKG_VERSION")
 }
+
+#[doc(hidden)]
+pub fn vendored() -> bool {
+    cfg!(libcurl_vendored)
+}
